@@ -12,7 +12,7 @@ import logging
 import requests
 
 from jira import JIRA
-from jira_commands.utils import dumpObject
+from jira_commands.utils import dump_object
 from thelogrus.yaml import readYamlFile
 
 
@@ -109,32 +109,33 @@ def makeIssueData(cli):
     returns dict
     """
     try:
-        if cli.json:
+        if hasattr(cli, "json"):
             issue_data = json.loads(cli.json)
             logging.debug(f"issue_data (from --json): {issue_data}")
         else:
             logging.debug("Starting with blank issue data")
             issue_data = {}
-    except AttributeError:
+    except AttributeError as missing_json:
         logging.warning("No json command line argument found")
+        raise missing_json
 
-    if cli.description:
+    if hasattr(cli, "description"):
         logging.debug(f"description: {cli.description}")
         issue_data["description"] = cli.description
 
-    if cli.issue_type:
+    if hasattr(cli, "issue_type"):
         logging.debug(f"issue_type: {cli.issue_type}")
         issue_data["issuetype"] = cli.issue_type
 
-    if cli.label:
+    if hasattr(cli, "label"):
         logging.debug(f"label: {cli.label}")
         issue_data["label"] = cli.label
 
-    if cli.project:
+    if hasattr(cli, "project"):
         logging.debug(f"project: {cli.project}")
         issue_data["project"] = cli.project
 
-    if cli.summary:
+    if hasattr(cli, "summary"):
         logging.debug(f"summary: {cli.summary}")
         issue_data["summary"] = cli.summary
 
@@ -189,7 +190,7 @@ class JiraTool:
             logging.debug(
                 f"Creating connection to {self.jira_server} with user {self.username}"
             )
-            self.connection = JIRA(options=jiraOptions, basic_auth=jiraBasicAuth)
+            self.connection = JIRA(options=jiraOptions, basic_auth=jiraBasicAuth)  # type: ignore
 
         if auth == "OAUTH":
             with open(self.oauth_private_key_pem_path, "r") as key_cert_file:
@@ -247,6 +248,7 @@ class JiraTool:
             return issue.update(fields=fields)
         except Exception as jiraConniption:
             logging.exception(jiraConniption)
+            raise jiraConniption
 
     def updateMultipleFields(self, ticket: str, fields: dict):
         """
@@ -258,6 +260,7 @@ class JiraTool:
             return issue.update(fields=fields)
         except Exception as jiraConniption:
             logging.exception(jiraConniption)
+            raise jiraConniption
 
     # Utility functions
     def assignTicket(self, ticket: str, assignee: str):
@@ -483,13 +486,13 @@ class JiraTool:
         print()
         print(f"ticket.fields.issuetype: {ticket.fields.issuetype}")
         print(f"ticket.fields.issuelinks: {ticket.fields.issuelinks}")
-        print(f"ticket.fields.issuelinks dump: {dumpObject(ticket.fields.issuelinks)}")
+        print(f"ticket.fields.issuelinks dump: {dump_object(ticket.fields.issuelinks)}")
         print()
         print(f"ticket.fields: {ticket.fields}")
         print()
         print(f"dir(ticket): {dir(ticket)}")
         print()
-        print(f"ticket.fields (dump): {dumpObject(ticket.fields)}")
+        print(f"ticket.fields (dump): {dump_object(ticket.fields)}")
 
     def getTicketDict(self, project: str):
         """
@@ -502,7 +505,7 @@ class JiraTool:
             tickets[singleIssue.key] = singleIssue
             logging.debug(f"{singleIssue.key} : {singleIssue}")
             logging.debug(f"{singleIssue.key} : fields {singleIssue.fields}")
-            logging.debug(f"dumpObj(singleIssue : {dumpObject(singleIssue)}")
+            logging.debug(f"dumpObj(singleIssue : {dump_object(singleIssue)}")
             logging.debug(" ")
         return tickets
 
@@ -578,7 +581,6 @@ class JiraTool:
                         data[opt["value"]] = opt["id"]
                         logging.debug(f"Setting data['{opt['value']}'] to {opt['id']}")
                 allowed[field] = data
-        logging.debug(f"allowed: {allowed}")
         return allowed
 
     def updateFieldDict(
